@@ -19,21 +19,9 @@
 #ifndef __UNIX2TCP_H__
 #define __UNIX2TCP_H__
 
-#include "list.h"
-
-typedef struct packet_struct {
-   char *data;
-   int len;
-} t_packet;
-
-typedef struct my_socket_struct {
-   int sock;
-   t_list *outqueue;
-} t_mysocket;
-
-typedef struct connection_struct {
-   t_mysocket in, out;
-   int inprogress;
-} t_connection;
+extern char *unixpath;
+extern char *raddrs;
+extern char *rports;
+extern volatile int quitasap;
 
 #endif /* __UNIX2TCP_H__ */
